<?php

namespace Drupal\media_keepeekdam\Service;

use Drupal\Core\Access\AccessManagerInterface;
use Drupal\Core\Access\AccessResult;
use Drupal\Core\Controller\ControllerResolverInterface;
use Drupal\Core\Session\AccountInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Symfony\Component\HttpFoundation\RequestStack;

/**
 * Class to Check Access to the Keepeek module.
 */
class AccessCheck {

  /**
   * A controller resolver object.
   *
   * @var \Symfony\Component\HttpKernel\Controller\ControllerResolverInterface
   */
  protected $controllerResolver;

  /**
   * The access manager.
   *
   * @var \Drupal\Core\Access\AccessManagerInterface
   */
  protected $accessManager;

  /**
   * The current user.
   *
   * @var \Drupal\Core\Session\AccountInterface
   */
  protected $account;

  /**
   * The request stack.
   *
   * @var \Symfony\Component\HttpFoundation\RequestStack
   */
  protected $requestStack;

  /**
   * Constructs a new AccessCheck instance.
   *
   * @param \Drupal\Core\Controller\ControllerResolverInterface $controller_resolver
   *   The controller resolver.
   * @param \Drupal\Core\Access\AccessManagerInterface $access_manager
   *   The access manager.
   * @param \Drupal\Core\Session\AccountInterface $account
   *   The current user.
   * @param \Symfony\Component\HttpFoundation\RequestStack $request_stack
   *   The request stack.
   */
  public function __construct(ControllerResolverInterface $controller_resolver, AccessManagerInterface $access_manager, AccountInterface $account, RequestStack $request_stack) {
    $this->controllerResolver = $controller_resolver;
    $this->accessManager = $access_manager;
    $this->account = $account;
    $this->requestStack = $request_stack;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('controller_resolver'),
      $container->get('access_manager'),
      $container->get('current_user'),
      $container->get('request_stack'),
    );
  }

  /**
   * Check Access to Keepeek media.
   *
   * @param string $type
   *   The type.
   * @param string $operation
   *   The operation.
   *
   * @return \Drupal\Core\Access\AccessResultAllowed|\Drupal\Core\Access\AccessResultForbidden|\Drupal\Core\Access\AccessResultNeutral
   *   The result.
   */
  public function keepeekImageMediaAccess(string $type, string $operation) {
    $permission = $operation . ' keepeek ' . $type . ' media';
    if ($operation === 'view') {
      // If the operation is 'view' then don't alter the access.
      return AccessResult::neutral();
    }
    return AccessResult::allowedIfHasPermissions($this->account, [$permission], 'OR');
  }

}
